/*
 * @(#)AccessorRunnable.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.accessor;

import java.awt.Component;

import chrriis.uihierarchy.Accessor;

/**
 * An action to be run by an accessor on the components held by its levels.
 * @version 1.0 2003.3.12
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public interface AccessorRunnable {

  /**
   * Run the action. This method will get called as many times as the accessor
   * contains levels, and sub levels if traversing.
   * @param component The component of the level for which the action is being
   * executed.
   * @param childrenAccessor An accessor created to access the children levels
   * of the level currently processed by the action.
   * @return The result of the operation, which can be null. The results of the
   * multiple calls to the action will be aggregated to an array by the accessor
   * itself. 
   */
  public Object run(Component component, Accessor childrenAccessor);

}
