/*
 * @(#)BorderHConstraints.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.constraints;

import java.awt.BorderLayout;
import java.awt.Container;

import chrriis.uihierarchy.SingleLevelAccessor;

/**
 * The constraints for a Border layout. Constraints are manipulated by the
 * <code>createConstraints</code> method, if they are a String.
 * <br><br>
 * The possible constraints are (case is insensitive):
 * <br>
 * <ul>
 * <li>center
 * <li>north
 * <li>south
 * <li>east
 * <li>west
 * </ul>
 * @version 1.1 2003.11.03
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class BorderHConstraints implements LayoutHConstraints {

  /**
   * Create the constraints for a border layout, if the parameter is a String.
   * @param accessor The accessor of the level for which to create the
   * constraints.
   * @param parentContainer The parent container.
   * @param constraints The constraints of the component.
   * @return The border layout constraints, or the original constraints if not a
   * String.
   */
  public Object createConstraints(SingleLevelAccessor accessor, Container parentContainer, Object constraints) {
    if(!(constraints instanceof String)) {
      return constraints;
    }
    String cons = ((String)constraints).trim().toLowerCase();
    if(cons.equals("center")) {
      return BorderLayout.CENTER;
    } else if(cons.equals("north")) {
      return BorderLayout.NORTH;
    } else if(cons.equals("west")) {
      return BorderLayout.WEST;
    } else if(cons.equals("east")) {
      return BorderLayout.EAST;
    } else if(cons.equals("south")) {
      return BorderLayout.SOUTH;
    }
    throw new IllegalArgumentException("\"" + constraints + "\" is not a valid constraint!");
  }

}
