/*
 * @(#)IllegalConstraintsException.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.constraints;

import java.awt.Container;

import chrriis.uihierarchy.SingleLevelAccessor;
import chrriis.uihierarchy.UIHException;

/**
 * An exception while interpreting the meaning of some constraints.
 * @version 1.0 2004.01.14
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class IllegalConstraintsException extends UIHException {

  /** The parent container of the component. */
  protected Container parentContainer;

  /** The constraints. */
  protected Object constraints;

  /**
   * Construct an IllegalConstraintsException.
   * @param accessor The accessor of the component for which the creation of
   * constraints failed.
   * @param parentContainer The parent of the component.
   * @param constraints The constraints that were processed.
   * @param target The throwable that triggered this constraints exception.
   */
  public IllegalConstraintsException(SingleLevelAccessor accessor, Container parentContainer, Object constraints, Throwable target) {
    super(accessor, "\"" + constraints + "\"", target);
    this.parentContainer = parentContainer;
    this.constraints = constraints;
  }

  /**
   * Get the parent of the component.
   * @return The parent container.
   */
  public Container getParentContainer() {
    return parentContainer;
  }

  /**
   * Get the constraints that failed the interpretation.
   * @return The constraints.
   */
  public Object getConstraints() {
    return constraints;
  }

}
