/*
 * @(#)ComponentCreator.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.creator;

import java.awt.Component;
import java.awt.Container;

import chrriis.uihierarchy.UIHConfig;

/**
 * The interface that all creators of components must implement.
 * @version 1.0 2003.10.24
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public interface ComponentCreator {

  /** Indicator of a node. */
  public static int NODE = 1;
  /** Indicator of a leaf. */
  public static int LEAF = 2;

  /**
   * Create a component from an object representation.
   * @param uihConfig The configuration in use.
   * @param parentContainer The container that will be the parent of the
   * component to create. The addition of the component to the parent will be
   * automatic so this method should not affect this behaviour. The parent can
   * be null when the node is a sub node.
   * @param component The component's representation from which to create the
   * component.
   * @param level The indication of the level of the component. It is either
   * <code>NODE</code> or <code>LEAF</code>. Root nodes are differentiated from
   * nodes by the fact that the parent container is null.
   * @return The component that matches the given representation, or null
   * otherwise.
   */
  public Component createComponent(UIHConfig uihConfig, Container parentContainer, Object component, int level);

}
